@@ -21,6 +21,10 @@
 
 #include "../my_config.h"
 
+extern "C"
+{
+} // end extern "C"
+
 #include <vector>
 
 #include "archive_options.hpp"
@@ -367,6 +371,7 @@ namespace libdar
 	    x_modified_data_detection = modified_data_detection::mtime_size;
 	    x_iteration_count = default_iteration_count;
 	    x_kdf_hash = hash_algo::sha1;
+	    x_sig_block_len.reset();
 	}
 	catch(...)
 	{
@@ -624,6 +629,7 @@ namespace libdar
 	x_modified_data_detection = ref.x_modified_data_detection;
 	x_iteration_count = ref.x_iteration_count;
 	x_kdf_hash = ref.x_kdf_hash;
+	x_sig_block_len = ref.x_sig_block_len;
     }
 
     void archive_options_create::move_from(archive_options_create && ref) noexcept
@@ -692,6 +698,7 @@ namespace libdar
 	x_modified_data_detection = move(ref.x_modified_data_detection);
 	x_iteration_count = move(ref.x_iteration_count);
 	x_kdf_hash = move(ref.x_kdf_hash);
+	x_sig_block_len = move(ref.x_sig_block_len);
     }
 
 	/////////////////////////////////////////////////////////
@@ -765,6 +772,7 @@ namespace libdar
 	    x_delta_sig_min_size = default_delta_sig_min_size;
 	    x_iteration_count = default_iteration_count;
 	    x_kdf_hash = hash_algo::sha1;
+	    x_sig_block_len.reset();
 	}
 	catch(...)
 	{
@@ -942,6 +950,7 @@ namespace libdar
 	    x_delta_sig_min_size = default_delta_sig_min_size;
 	    x_iteration_count = default_iteration_count;
 	    x_kdf_hash = hash_algo::sha1;
+	    x_sig_block_len.reset();
 	}
 	catch(...)
 	{
@@ -1152,6 +1161,7 @@ namespace libdar
 	    x_delta_sig_min_size = ref.x_delta_sig_min_size;
 	    x_iteration_count = ref.x_iteration_count;
 	    x_kdf_hash = ref.x_kdf_hash;
+	    x_sig_block_len = ref.x_sig_block_len;
 	}
 	catch(...)
 	{
@@ -1208,6 +1218,7 @@ namespace libdar
 	x_delta_sig_min_size = move(ref.x_delta_sig_min_size);
 	x_iteration_count = move(ref.x_iteration_count);
 	x_kdf_hash = move(ref.x_kdf_hash);
+	x_sig_block_len = move(ref.x_sig_block_len);
     }
 
     void archive_options_merge::nullifyptr() noexcept
