@@ -1,6 +1,6 @@
 /*********************************************************************/
 // dar - disk archive - a backup/restoration program
-// Copyright (C) 2002-2018 Denis Corbin
+// Copyright (C) 2002-2019 Denis Corbin
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -43,7 +43,7 @@ namespace libdar
 	tlv_list() = default;                     ///< builds an empty list
 	tlv_list(generic_file & f) { init(f); };  ///< builds a list from a file
 	tlv_list(const tlv_list & ref) = default;
-	tlv_list(tlv_list && ref) noexcept = default;
+	tlv_list(tlv_list && ref) = default;
 	tlv_list & operator = (const tlv_list & ref) = default;
 	tlv_list & operator = (tlv_list && ref) noexcept = default;
 	~tlv_list() = default;
